@@ -61,6 +61,7 @@ core_articles <- function(id, metadata = TRUE, fulltext = FALSE,
   extractedUrls = FALSE, faithfulMetadata = FALSE, key = NULL,
   method = "GET", parse = TRUE, ...) {
 
+  assert(parse, "logical")
   core_parse(core_articles_(
     id, metadata, fulltext, citations, similar, duplicate,
     urls, extractedUrls, faithfulMetadata, key, method, ...), parse)
@@ -90,6 +91,9 @@ core_articles_ <- function(id, metadata = TRUE, fulltext = FALSE,
                                call. = FALSE)
       core_GET(path = file.path("articles/get", id), key, args, ...)
     },
-    `POST` = core_POST(path = "articles/get", key, args, id, ...)
+    `POST` = {
+      id = jsonlite::toJSON(id, auto_unbox = TRUE)
+      core_POST(path = "articles/get", key, args, id, ...)
+    }
   )
 }
