@@ -4,12 +4,12 @@
 #' @template all
 #' @param query (character) query string, required
 #' @param page (character) page number (default: 1), optional
-#' @param limit (character) records to return (default: 10, minimum: 10),
-#' optional
+#' @param limit (character) records to return (default: 10, minimum: 10,
+#' maximum: 100), optional
 #' @details `core_search` does the HTTP request and parses, while
 #' `core_search_` just does the HTTP request, gives back JSON as a character
 #' string
-#' @references <https://core.ac.uk/docs/#!/all/search>
+#' @references https://core.ac.uk/docs/#!/all/search
 #' @examples \dontrun{
 #' core_search(query = 'ecology')
 #' core_search(query = 'ecology', parse = FALSE)
@@ -18,13 +18,15 @@
 #' core_search_(query = 'ecology')
 #' library("jsonlite")
 #' jsonlite::fromJSON(core_search_(query = 'ecology'))
-#' 
-#' query <- c('data mining', 'machine learning', 'semantic web')
 #'
 #' # post request
+#' query <- c('data mining', 'machine learning', 'semantic web')
 #' res <- core_search(query)
-#' head(res$data)
-#' res$data$id
+#' res
+#' res$status
+#' res$totalHits
+#' res$data
+#' head(res$data[[1]])
 #' }
 core_search <- function(query, page = 1, limit = 10, key = NULL,
                         parse = TRUE, ...) {
@@ -35,12 +37,9 @@ core_search <- function(query, page = 1, limit = 10, key = NULL,
 #' @rdname core_search
 core_search_ <- function(query, page = 1, limit = 10, key = NULL, ...) {
   must_be(limit)
-
-  if(as.character(length(query) > 1)){
+  if (length(query) > 1) {
     queries <- create_batch_query_list(query, page, limit)
-    args <- NULL
-    
-    core_POST(path = "search", key, args, queries, ...)
+    core_POST(path = "search", key, NULL, queries, ...)
   } else {
     core_GET(path = file.path("search", query), key,
              list(page = page, pageSize = limit), ...)
