@@ -2,6 +2,19 @@ core_base <- function() "https://core.ac.uk"
 
 cp <- function(x) Filter(Negate(is.null), x)
 
+errs <- function(x, content_type="application/json") {
+  x$raise_for_ct(content_type)
+  if (x$status_code >= 400) {
+    tt <- tryCatch(x$parse("UTF-8"), error = function(e) e)
+    if (inherits(tt, "character")) {
+      tt <- tryCatch(jsonlite::fromJSON(tt), error = function(e) e)
+      stop(sprintf("(status %s)", x$status_code), " ", tt$status %||% tt$error$message,
+        call. = FALSE)
+    }
+    x$raise_for_status()
+  }
+}
+
 core_GET <- function(path, key, args, ...){
   cli <- crul::HttpClient$new(
     url = core_base(),
@@ -9,26 +22,23 @@ core_GET <- function(path, key, args, ...){
   )
   temp <- cli$get(
     path = file.path("api-v2", path),
-    query = cp(args),
-    ...
+    query = cp(args), ...
   )
-  temp$raise_for_status()
-  stopifnot(temp$response_headers$`content-type` == 'application/json')
+  errs(temp)
   temp$parse("UTF-8")
 }
 
-core_POST <- function(path, key, args, body, ...){
+core_POST <- function(path, key, query, body, ...){
   cli <- crul::HttpClient$new(
     url = core_base(),
     headers = list(apiKey = check_key(key))
+    # verbose = crul::curl_verbose()
   )
   temp <- cli$post(
     path = file.path("api-v2", path),
-    query = cp(args),
-    body = jsonlite::toJSON(body, auto_unbox = TRUE), encode = "json", ...
+    query = cp(query), body = body, encode = "json", ...
   )
-  temp$raise_for_status()
-  stopifnot(temp$response_headers$`content-type` == 'application/json')
+  errs(temp)
   temp$parse("UTF-8")
 }
 
@@ -50,7 +60,7 @@ core_GET_disk <- function(path, id, key, overwrite, ...){
   temp <- cli$get(path = file.path("api-v2", path), disk = fpath, ...)
   # unlink/delete file if http error code
   if (temp$status_code > 201) unlink(fpath)
-  temp$raise_for_status()
+    errs(temp, "application/pdf")
   temp$content
 }
 
@@ -104,3 +114,14 @@ asl <- function(z) {
     return(z)
   }
 }
+
+`%||%` <- function (x, y) if (is.null(x)) y else x
+
+assert <- function (x, y) {
+  if (!is.null(x)) {
+    if (!inherits(x, y)) {
+      stop(deparse(substitute(x)), " must be of class ",
+        paste0(y, collapse = ", "), call. = FALSE)
+    }
+  }
+}
